@@ -16,18 +16,25 @@
  * Inc., 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA
  */
 
+#include <config.h>
+
 #include <errno.h>
 #include <sys/types.h>
 #include <dirent.h>
 #include <string.h>
 
 #include <gio/gio.h>
-#include <gst/gst.h>
-
 #include <gdk-pixbuf/gdk-pixbuf.h>
 
-#include "audio-metadata.h"
+#if ENABLE_GST
+#include <gst/gst.h>
 #include "gst-helper.h"
+#else
+#include "stdlib.h" // for atoi()
+#include <hxthumb.h>
+#endif
+
+#include "audio-metadata.h"
 #include "metadata-defines.h"
 
 struct _metametadata {
@@ -108,6 +115,7 @@ write_thumbnail (GFile     *file,
     return uri;
 }
 
+#if ENABLE_GST
 static void
 parse_tags (const GstTagList *tags,
             const char       *tag,
@@ -231,6 +239,7 @@ parse_tags (const GstTagList *tags,
 
     /* Doesn't handle CONDUCTOR */
 }
+#endif
 
 static guint
 get_track_from_file (GFile *file)
@@ -347,7 +356,12 @@ find_art_in_directory (GFile *file)
         }
 
         if (g_ascii_strncasecmp (d_ent->d_name, "AlbumArt", 8) == 0) {
-            if (g_ascii_strcasecmp (d_ent->d_name + 8, "Small.jpg") == 0) {
+            if (g_ascii_strcasecmp (d_ent->d_name + 8, ".jpg") == 0) {
+                /* We've found AlbumArt.jpg */
+                album_art = g_strdup (d_ent->d_name);
+                break;
+            } else if (g_ascii_strcasecmp (d_ent->d_name + 8,
+                                           "Small.jpg") == 0) {
                 /* We've found AlbumArtSmall.jpg */
                 small = g_strdup (d_ent->d_name);
             } else {
@@ -467,6 +481,7 @@ sanitise_metadata (GFile      *file,
     }
 }
 
+#if ENABLE_GST
 /* Return TRUE if we have hit EOS or error */
 static gboolean
 parse_message (GstMessage *msg,
@@ -511,6 +526,73 @@ parse_message (GstMessage *msg,
     return FALSE;
 }
 
+#else
+
+static void
+parse_helix_tags(void               *user_data,
+                 eDtdrMediainfoType  media_info_type,
+                 char               *media_info_name,
+                 void               *media_info_value)
+{
+  struct _metametadata *mmd = (struct _metametadata *) user_data;
+  GHashTable *metadata = (GHashTable *) mmd->metadata;
+  char *new_media_info_name = media_info_name;
+  gboolean is_video = FALSE;
+
+    if (g_str_has_prefix (media_info_name,"video") ||
+        g_str_has_prefix (media_info_name,"audio")) {
+        /* Helix Framework support media content with >1 audio track
+           and/or >1 video stream. it will use prefix "video?-" or "audio?-"
+           to distinguish each stream. we just ignore this prefix here. */
+
+        if (g_str_has_prefix (media_info_name, "video") ) {
+            is_video = TRUE;
+        }
+
+        if (g_ascii_isdigit (media_info_name[5]))  {
+            if (media_info_name[6] == '-') {
+                new_media_info_name = media_info_name + 7;
+            }
+        }
+    }
+
+    if (g_str_equal (new_media_info_name, HELIX_TAG_TITLE)) {
+        g_hash_table_insert (metadata, METADATA_AUDIO_TITLE,
+                             g_strdup ((char *) media_info_value));
+    } else if (g_str_equal (new_media_info_name, HELIX_TAG_AUTHOR)) {
+        g_hash_table_insert (metadata, METADATA_AUDIO_ARTIST,
+                             g_strdup ((char *) media_info_value));
+    } else if (g_str_equal (new_media_info_name, HELIX_TAG_ABSTRACT)) {
+        g_hash_table_insert (metadata, METADATA_AUDIO_ALBUM,
+                             g_strdup ((char *) media_info_value));
+    } else if (g_str_equal (new_media_info_name, HELIX_TAG_GENRE)) {
+        g_hash_table_insert (metadata, METADATA_AUDIO_GENRE,
+                             g_strdup ((char*) media_info_value));
+    } else if (g_str_equal (new_media_info_name, HELIX_TAG_DURATION)) {
+        /* FIXME: Should this use GPOINTER_TO_INT? */
+        g_hash_table_insert (metadata, METADATA_AUDIO_DURATION,
+                             g_strdup_printf("%d",
+                                             (guint) media_info_value / 1000));
+    } else if (g_str_equal (new_media_info_name, HELIX_TAG_COPYRIGHT)) {
+        g_hash_table_insert (metadata, METADATA_AUDIO_COPYRIGHT,
+                             g_strdup ((char*) media_info_value));
+    } else if (g_str_equal (new_media_info_name, HELIX_TAG_MIMETYPE)) {
+        if(g_hash_table_lookup (metadata, METADATA_FILE_MIMETYPE) == NULL ||
+           is_video == TRUE) {
+            g_hash_table_insert (metadata, METADATA_FILE_MIMETYPE,
+                                 g_strdup ((char*) media_info_value));
+        }
+    } else if (g_str_equal (new_media_info_name, HELIX_TAG_CHANNELS)) {
+        /* HELIX provides it; but not used by bickley yet. */
+    } else if (g_str_equal (new_media_info_name, HELIX_TAG_BITSPERSAMPLE)) {
+        /* HELIX provides it; but not used by bickley yet. */
+    } else if (g_str_equal (new_media_info_name, HELIX_TAG_SAMPLERATE)) {
+        /* HELIX provides it; but not used by bickley yet. */
+    }
+}
+
+#endif
+
 #if __WORDSIZE == 64
 #define G_GINT64_MODIFIER "l"
 # else
@@ -522,18 +604,24 @@ bkl_task_audio_get_metadata (GFile      *file,
                              const char *mimetype,
                              GHashTable *metadata)
 {
+#if ENABLE_GST
     GstElement *playbin, *audio_sink, *video_sink;
     GstStateChangeReturn state;
-    char *uri;
     int count = 0;
+#else
+    static struct _metametadata mmd;
+#endif
+    char *uri;
 
-    if (!g_str_has_prefix (mimetype, "audio/") ||
-        g_str_equal (mimetype, "audio/x-mpegurl")) {
+    if ((!g_str_has_prefix (mimetype, "audio/") ||
+         g_str_equal (mimetype, "audio/x-mpegurl")) &&
+        !g_strrstr (mimetype, "vnd.rn-realmedia")) {
         return FALSE;
     }
 
     uri = g_file_get_uri (file);
 
+#if ENABLE_GST
     playbin = gst_element_factory_make ("playbin", "playbin");
     audio_sink = gst_element_factory_make ("fakesink", "audiosink");
     video_sink = gst_element_factory_make ("fakesink", "videosink");
@@ -591,6 +679,15 @@ bkl_task_audio_get_metadata (GFile      *file,
     gst_element_set_state (playbin, GST_STATE_NULL);
     g_object_unref (playbin);
 
+#else
+    mmd.metadata = metadata;
+    mmd.file = file;
+
+    GetMetaData (uri, parse_helix_tags, (void*) &mmd);
+
+    g_free (uri);
+#endif
+
     sanitise_metadata (file, metadata);
     return TRUE;
 }
