@@ -145,7 +145,7 @@ bkl_source_gconf_investigate_uris (BklSource *source,
 {
     BklSourceGConf *gconf = (BklSourceGConf *) source;
     GPtrArray *fa;
-    int i;
+    int i, increase;
 
     fa = g_ptr_array_new ();
 
@@ -176,7 +176,13 @@ bkl_source_gconf_investigate_uris (BklSource *source,
         g_ptr_array_add (fa, uri);
     }
 
-    gconf->uri_count += bkl_orbiter_investigate_files (source, fa);
+    increase = bkl_orbiter_investigate_files (source, fa);
+    gconf->uri_count += increase;
+#ifdef DEBUG
+    g_print ("(%s): Increasing uri count by %d to %d\n", source->name,
+             increase, gconf->uri_count);
+#endif
+
     /* investigate_files takes ownership of the uris */
     g_ptr_array_free (fa, TRUE);
 }
@@ -256,6 +262,10 @@ bkl_source_gconf_add_item (BklSource  *source,
     BklItem *old;
     BklSourceGConf *gconf = (BklSourceGConf *) source;
 
+#ifdef DEBUG
+    g_print ("(%s): Completed: %s\n", source->name, uri);
+#endif
+
     old = bkl_db_get_item (source->db, uri, error);
     if (*error != NULL) {
         if ((*error)->code != KOZO_DB_ERROR_KEY_NOT_FOUND) {
@@ -298,6 +308,10 @@ bkl_source_gconf_add_item (BklSource  *source,
     }
 
     gconf->uri_count--;
+#ifdef DEBUG
+    g_print ("(%s): Reduced uri count to: %d\n", source->name,
+             gconf->uri_count);
+#endif
     if (gconf->uri_count == 0) {
         bkl_source_completed (source);
     }
@@ -526,7 +540,6 @@ kozo_init (BklSourceGConf *source,
 
     s->db = bkl_db_get (name, &error);
     if (s->db == NULL) {
-        g_print ("fialed: %p\n", error);
         if (error->code == KOZO_DB_ERROR_VERSION_MISMATCH) {
             g_warning ("The database for %s is out of date.\nIt should be removed and regenerated.\n%s", name, error->message);
         } else {
